API Reference
=============

Auto-generated API documentation from source code docstrings.

.. toctree::
   :maxdepth: 2

   server
   models
   graph
   parsers
   regions
   rag
   storage
   synthesis
   theory
   verification
